# Generated by Django 5.1.3 on 2024-11-28 15:00

from django.db import migrations


class Migration(migrations.Migration):
    """Fixes `badly formed hexadecimal UUID string` exception.

    ... raised when running `model_cls.objects.all().delete()` on some
    report models (with existing int [autoincrement] values in their id
    fields), that Django is unable to handle.
    """

    dependencies = [
        ("intecomm_reports", "0028_auto_20241031_0602"),
    ]

    operations = [
        migrations.RunSQL("delete from intecomm_reports_missingvldrawdates;"),
        migrations.RunSQL("delete from intecomm_reports_vlsummary6m;"),
        migrations.RunSQL("delete from intecomm_reports_vlsummary9m;"),
    ]
