# Generated by Django 5.1 on 2024-10-04 14:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_reports", "0021_onstudymissinglabvalues_onstudymissingvalues_and_more"),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="ApptLocationQa",
            new_name="AppointmentLocationQa",
        ),
        migrations.RenameIndex(
            model_name="appointmentlocationqa",
            new_name="intecomm_re_modifie_c2590e_idx",
            old_name="intecomm_re_modifie_4638df_idx",
        ),
        migrations.RenameIndex(
            model_name="appointmentlocationqa",
            new_name="intecomm_re_user_mo_50d666_idx",
            old_name="intecomm_re_user_mo_927bd2_idx",
        ),
    ]
