# Generated by Django 5.1.2 on 2024-10-31 02:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_reports", "0026_vlsummary6m_device_created_and_more"),
    ]

    operations = [
        migrations.DeleteModel(
            name="OnStudyMissingLabValues",
        ),
        migrations.DeleteModel(
            name="OnStudyMissingValues",
        ),
    ]
