# Generated by Django 5.1 on 2024-08-29 12:58

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_action_item", "0037_remove_actionitem_reference_model_and_more"),
        ("intecomm_subject", "0188_delete_diagnoses"),
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.RenameModel(
            old_name="BloodResultsLipid",
            new_name="BloodResultsLipids",
        ),
        migrations.RenameModel(
            old_name="HistoricalBloodResultsLipid",
            new_name="HistoricalBloodResultsLipids",
        ),
        migrations.RenameIndex(
            model_name="bloodresultslipids",
            new_name="intecomm_su_subject_28e6f3_idx",
            old_name="intecomm_su_subject_0dd0d1_idx",
        ),
        migrations.RenameIndex(
            model_name="bloodresultslipids",
            new_name="intecomm_su_subject_081f29_idx",
            old_name="intecomm_su_subject_d3a470_idx",
        ),
        migrations.RenameIndex(
            model_name="bloodresultslipids",
            new_name="intecomm_su_modifie_40ed7c_idx",
            old_name="intecomm_su_modifie_2deb12_idx",
        ),
        migrations.RenameIndex(
            model_name="bloodresultslipids",
            new_name="intecomm_su_user_mo_8696f9_idx",
            old_name="intecomm_su_user_mo_4870e2_idx",
        ),
    ]
